@@ -1,6 +1,6 @@
 from yarl import URL
 
-from ..base_functions.base_functions import log, logger, make_title_safe, get_filename_and_ext, get_db_path
+from ..base_functions.base_functions import get_filename_and_ext, log, logger, make_title_safe
 from ..base_functions.data_classes import DomainItem, MediaItem
 from ..base_functions.error_classes import NoExtensionFailure
 from ..base_functions.sql_helper import SQLHelper
@@ -46,8 +46,7 @@ class EromeCrawler:
                 except NoExtensionFailure:
                     logger.debug("Couldn't get extension for %s", str(url))
                     continue
-                link_path = await get_db_path(link)
-                complete = await self.SQL_Helper.check_complete_singular("erome", link_path)
+                complete = await self.SQL_Helper.check_complete_singular("erome", link)
                 media = MediaItem(link, url, complete, filename, ext, filename)
                 await domain_obj.add_media(title, media)
 
@@ -59,13 +58,11 @@ class EromeCrawler:
                 except NoExtensionFailure:
                     logger.debug("Couldn't get extension for %s", str(link))
                     continue
-                link_path = await get_db_path(link)
-                complete = await self.SQL_Helper.check_complete_singular("erome", link_path)
+                complete = await self.SQL_Helper.check_complete_singular("erome", link)
                 media = MediaItem(link, url, complete, filename, ext, filename)
                 await domain_obj.add_media(title, media)
 
-            url_path = await get_db_path(url)
-            await self.SQL_Helper.insert_domain("erome", url_path, domain_obj)
+            await self.SQL_Helper.insert_domain("erome", url, domain_obj)
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
             await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
