@@ -1,6 +1,6 @@
 from yarl import URL
 
-from ..base_functions.base_functions import log, logger, get_db_path, get_filename_and_ext
+from ..base_functions.base_functions import get_filename_and_ext, log, logger
 from ..base_functions.data_classes import AlbumItem, MediaItem
 from ..base_functions.sql_helper import SQLHelper
 from ..client.client import ScrapeSession
@@ -19,12 +19,11 @@ class SaintCrawler:
         try:
             soup = await session.get_BS4(url)
             link = URL(soup.select_one('video[id=main-video] source').get('src'))
-            url_path = await get_db_path(link)
-            complete = await self.SQL_Helper.check_complete_singular("saint", url_path)
+            complete = await self.SQL_Helper.check_complete_singular("saint", link)
             filename, ext = await get_filename_and_ext(link.name)
             media_item = MediaItem(link, url, complete, filename, ext, filename)
             await album_obj.add_media(media_item)
-            await self.SQL_Helper.insert_album("saint", url_path, album_obj)
+            await self.SQL_Helper.insert_album("saint", link, album_obj)
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
