@@ -130,7 +130,7 @@ class ShareXCrawler:
         """Gets final links and adds to domain_obj"""
         try:
             soup = await session.get_BS4(url)
-            if url.host == 'jpg.fish' or url.host == 'jpg.church':
+            if 'jpg.fish' in url.host or 'jpg.church' in url.host:
                 links = soup.select("a[href*=img] img")
             else:
                 links = soup.select("a[href*=image] img")
